@@ -7,6 +7,7 @@ from typing import Any, Dict, List, Optional
 import kubernetes
 from timeout_sampler import TimeoutWatch
 
+from ocp_resources.constants import TIMEOUT_5SEC
 from ocp_resources.exceptions import ExecOnPodError
 from ocp_resources.node import Node
 
@@ -510,8 +511,8 @@ class Pod(NamespacedResource):
         if rcstring is None:
             raise ExecOnPodError(command=command, rc=-1, out="", err=stream_closed_error)
 
-        stdout = resp.read_stdout(timeout=5)
-        stderr = resp.read_stderr(timeout=5)
+        stdout = resp.read_stdout(timeout=TIMEOUT_5SEC)
+        stderr = resp.read_stderr(timeout=TIMEOUT_5SEC)
 
         if rcstring == "Success" or ignore_rc:
             return stdout
